@@ -1,4 +1,3 @@
-from re import S
 from typing import Any
 from urllib.parse import quote
 from .json import JSON
@@ -11,7 +10,6 @@ class Res:
         self._code: int = 200
         self._body: bytes = b''
         self._headers: dict[str, str] = {}
-        self._media_type = None
         self._json = json
 
     @property
@@ -24,8 +22,6 @@ class Res:
 
     @property
     def headers(self) -> dict[str, str]:
-        if self._media_type is not None:
-            self._headers['content-type'] = self._media_type
         return self._headers
 
     @headers.setter
@@ -43,15 +39,15 @@ class Res:
         self._body = body
 
     def json(self, data: Any) -> None:
-        self._media_type = "application/json"
+        self._headers['content-type'] = "application/json"
         self._body = self._json.encode(data)
 
     def text(self, text: str) -> None:
-        self._media_type = 'text/plain'
+        self._headers['content-type'] = 'text/plain'
         self._body = text.encode('utf-8')
 
     def html(self, html: str) -> None:
-        self._media_type = 'text/html'
+        self._headers['content-type'] = 'text/html'
         self._body = html.encode('utf-8')
 
     def redirect(self, url: str) -> None:
